@@ -60,10 +60,10 @@ from .proto.exchange import (
 
 from .constant import Network
 
-DEFAULT_TIMEOUTHEIGHT_SYNC_INTERVAL = 10  # seconds
-DEFAULT_TIMEOUTHEIGHT = 20  # blocks
+DEFAULT_TIMEOUTHEIGHT_SYNC_INTERVAL = 20  # seconds
+DEFAULT_TIMEOUTHEIGHT = 30  # blocks
 DEFAULT_SESSION_RENEWAL_OFFSET = 120  # seconds
-DEFAULT_BLOCK_TIME = 3  # seconds
+DEFAULT_BLOCK_TIME = 2  # seconds
 
 
 logging.basicConfig(format="%(levelname)s:%(message)s", level=logging.INFO)
@@ -617,7 +617,7 @@ class AsyncClient:
         req = spot_exchange_rpc_pb.OrdersHistoryRequest(
             market_id=market_id,
             direction=kwargs.get("direction"),
-            order_type=kwargs.get("order_type"),
+            order_types=kwargs.get("order_types"),
             subaccount_id=kwargs.get("subaccount_id"),
             skip=kwargs.get("skip"),
             limit=kwargs.get("limit"),
@@ -737,7 +737,7 @@ class AsyncClient:
         req = derivative_exchange_rpc_pb.OrdersHistoryRequest(
             market_id=market_id,
             direction=kwargs.get("direction"),
-            order_type=kwargs.get("order_type"),
+            order_types=kwargs.get("order_types"),
             subaccount_id=kwargs.get("subaccount_id"),
             skip=kwargs.get("skip"),
             limit=kwargs.get("limit"),
